@@ -78,6 +78,7 @@ OC.L10N.register(
     "_including %n hidden_::_including %n hidden_" : ["incluyendo %n oculto","incluyendo %n ocultos","incluyendo %n ocultos"],
     "You do not have permission to upload or create files here" : "No tiene permiso para crear o cargar archivos aquí",
     "_Uploading %n file_::_Uploading %n files_" : ["Subiendo %n archivo","Cargando %n archivos","Cargando %n archivos"],
+    "New" : "Nuevo",
     "New file/folder menu" : "Menú de carpeta/archivo nuevo",
     "Select file range" : "Seleccione rango de archivos",
     "{used}%" : "{used}%",
@@ -152,7 +153,6 @@ OC.L10N.register(
     "A file has been added to or removed from your <strong>favorites</strong>" : "Un archivo ha sido agregado o eliminado de tus <strong>favoritos</strong>",
     "A file or folder has been <strong>changed</strong>" : "Un archivo o carpeta ha sido <strong>cambiado</strong>",
     "A favorite file or folder has been <strong>changed</strong>" : "Un archivo o carpeta favorito ha sido <strong>cambiado</strong>",
-    "All files" : "Todos los archivos",
     "Upload (max. %s)" : "Cargar (max. %s)",
     "Accept" : "Aceptar",
     "Reject" : "Rechazar",
@@ -166,12 +166,15 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "Se ha completado la transferencia de propiedad de {path} a {user}.",
     "in %s" : "en %s",
     "File Management" : "Administración de Archivos",
+    "You don’t have permission to upload or create files here" : "No cuentas con los permisos para cargar o crear archivos aquí",
+    "Folder name" : "Nombre de la carpeta",
     "Name cannot be empty" : "El nombre no puede estar en blanco",
-    "Select all" : "Seleccionar todo",
+    "File not found" : "Archivo no encontrado",
     "Storage informations" : "Informaciones de almacenamiento",
     "{usedQuotaByte} used" : "{usedQuotaByte} utilizados",
     "{relative}% used" : "{relative}% utilizado",
     "Could not refresh storage stats" : "No fue posible actualizar las estadísticas de almacenamiento",
+    "Your storage is full, files can not be updated or synced anymore!" : "Tu espacio está lleno. ¡Los archivos ya no se pueden actualizar o sincronizar!",
     "Transfer ownership of a file or folder" : "Transferir la propiedad de un archivo o carpeta",
     "Choose file or folder to transfer" : "Elegir archivo o carpeta para transferir",
     "Change" : "Cambiar",
@@ -183,9 +186,12 @@ OC.L10N.register(
     "Unknown error" : "Se presentó un error desconocido",
     "Ownership transfer request sent" : "Enviada la solicitud de transferencia de propiedad",
     "Cannot transfer ownership of a file or folder you do not own" : "No puedes transferir la propiedad de un archivo o directorio del cual no eres propietario",
+    "Add" : "Guardar",
     "No files in here" : "No hay archivos aquí",
     "Upload some content or sync with your devices!" : "¡Carga algún contenido o sincroniza con tus dispositivos!",
     "Go back" : "Regresar",
+    "Shared by link" : "Compartido por liga",
+    "Shared" : "Compartido",
     "Open the files app settings" : "Abrir la configuración de la app Archivos",
     "Files settings" : "Configuración de archivos",
     "Show hidden files" : "Mostrar archivos ocultos",
@@ -204,32 +210,29 @@ OC.L10N.register(
     "Blank" : "Vacío",
     "Unable to create new file from template" : "No se ha podido crear un nuevo archivo desde la plantilla",
     "Delete permanently" : "Borrar permanentemente",
-    "Set up templates folder" : "Configura una carpeta para plantillas",
     "Templates" : "Plantillas",
     "Unable to initialize the templates directory" : "No se ha podido iniciar la carpeta de plantillas",
     "No favorites yet" : "Aún no hay favoritos",
     "Files and folders you mark as favorite will show up here" : "Los archivos y carpetas que marques como favoritos se mostrarán aquí. ",
-    "Toggle %1$s sublist" : "Alternar %1$s sublista",
-    "Toggle grid view" : "Vista de cuadrícula",
+    "All files" : "Todos los archivos",
     "No entries found in this folder" : "No se encontraron elementos en esta carpeta",
+    "Select all" : "Seleccionar todo",
     "Upload too large" : "La carga es demasido grande",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Los archivos que estás intentando cargar sobrepasan el tamaño máximo permitido para la carga de archivos en este servidor.",
     "Text file" : "Archivo de texto",
     "New text file.txt" : "Nuevo ArchivoDeTexto.txt",
-    "Storage invalid" : "El almacenamiento es inválido",
     "You can only favorite a single file or folder at a time" : "Solo puedes marcar como favorito un solo archivo o carpeta cada vez",
-    "Unlimited" : "Ilimitado",
     "Search users" : "Buscar usuarios",
     "Cancel" : "Cancelar",
-    "%s used" : "%s usado",
-    "%s%%" : "%s%%",
-    "%1$s of %2$s used" : "%1$s de %2$s usados",
+    "Set up templates folder" : "Configura una carpeta para plantillas",
+    "Toggle %1$s sublist" : "Alternar %1$s sublista",
+    "Toggle grid view" : "Vista de cuadrícula",
     "Deleted files" : "Papelera",
     "Shares" : "Elementos compartidos",
     "Shared with others" : "Compartido con otros",
     "Shared with you" : "Compartido con usted",
-    "Shared by link" : "Compartido por liga",
     "Deleted shares" : "Recursos compartidos eliminados",
-    "Pending shares" : "Recursos compartidos pendientes"
+    "Pending shares" : "Recursos compartidos pendientes",
+    "Choose" : "Seleccionar"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
