@@ -22,6 +22,8 @@ OC.L10N.register(
     "An unknown error has occurred" : "Une erreur inconnue est survenue",
     "File could not be uploaded" : "Le fichier n'a pas pu être téléversé",
     "Uploading …" : "Envoi en cours...",
+    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
+    "Uploading … ({currentNumber}/{total})" : "Téléversement en cours… ({currentNumber}/{total})",
     "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} sur {totalSize} ({bitrate})",
     "Uploading that item is not supported" : "L'envoi de cet élément n'est pas supporté",
     "Target folder does not exist any more" : "Le dossier cible n'existe plus",
@@ -32,6 +34,7 @@ OC.L10N.register(
     "Move" : "Déplacer",
     "Copy" : "Copier",
     "Choose target folder" : "Sélectionner le dossier cible",
+    "Set reminder" : "Définir un rappel",
     "Edit locally" : "Éditer localement",
     "Open" : "Ouvrir",
     "Delete file" : "Supprimer le fichier",
@@ -50,7 +53,7 @@ OC.L10N.register(
     "This operation is forbidden" : "Cette opération est interdite",
     "This directory is unavailable, please check the logs or contact the administrator" : "Ce répertoire est indisponible, merci de consulter les journaux ou de contacter votre administrateur",
     "Storage is temporarily not available" : "Le support de stockage est temporairement indisponible",
-    "Could not move \"{file}\", target exists" : "Impossible de déplacer \"{file}\", la cible existe",
+    "Could not move \"{file}\", target exists" : "Impossible de déplacer « {file} », la cible existe",
     "Could not move \"{file}\"" : "Impossible de déplacer \"{file}\"",
     "copy" : "copie",
     "Could not copy \"{file}\", target exists" : "Impossible de copier \"{file}\", la cible existe",
@@ -61,9 +64,9 @@ OC.L10N.register(
     "{newName} already exists" : "{newName} existe déjà",
     "Could not rename \"{fileName}\", it does not exist any more" : "Impossible de renommer \"{fileName}\" car il n'existe plus",
     "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Le nom \"{targetName}\" est déjà utilisé dans le dossier \"{dir}\". Merci de choisir un nom différent.",
-    "Could not rename \"{fileName}\"" : "Impossible de renommer \"{fileName}\"",
+    "Could not rename \"{fileName}\"" : "Impossible de renommer « {fileName} »",
     "Could not create file \"{file}\"" : "Impossible de créer le fichier \"{file}\"",
-    "Could not create file \"{file}\" because it already exists" : "Impossible de créer le fichier \"{file}\" car il existe déjà",
+    "Could not create file \"{file}\" because it already exists" : "Impossible de créer le fichier « {file} » car il existe déjà",
     "Could not create folder \"{dir}\" because it already exists" : "Impossible de créer le dossier \"{dir}\" car il existe déjà",
     "Could not fetch file details \"{file}\"" : "Impossible de récupérer les détails du fichier \"{file}\"",
     "Error deleting file \"{fileName}\"." : "Erreur à la suppression du fichier \"{fileName}\".",
@@ -78,6 +81,7 @@ OC.L10N.register(
     "_including %n hidden_::_including %n hidden_" : ["dont %n masqué","dont %n masqués","dont %n masqués"],
     "You do not have permission to upload or create files here" : "Vous n'avez pas la permission de téléverser ou de créer des fichiers ici",
     "_Uploading %n file_::_Uploading %n files_" : ["Téléversement de %n fichier","Envoi de %n fichiers","Envoi de %n fichiers"],
+    "New" : "Nouveau",
     "New file/folder menu" : "Menu nouveau fichier/dossier",
     "Select file range" : "Activer la sélection d'une plage de fichiers",
     "{used}%" : "{used}%",
@@ -106,9 +110,7 @@ OC.L10N.register(
     "New folder" : "Nouveau dossier",
     "Create new folder" : "Créer un nouveau dossier",
     "Upload file" : "Téléverser un fichier",
-    "Recent" : "Récent",
-    "This file has the tag {tag}" : "Ce fichier a l'étiquette {tag}",
-    "This file has the tags {firstTags} and {lastTag}" : "Ce fichier a les étiquettes {firstTags} et {lastTag}",
+    "Recent" : "Récents",
     "Not favorited" : "Non marqué comme favori",
     "Remove from favorites" : "Retirer des favoris",
     "Add to favorites" : "Ajouter aux favoris",
@@ -154,7 +156,6 @@ OC.L10N.register(
     "A file has been added to or removed from your <strong>favorites</strong>" : "Un fichier a été ajouté ou retiré de vos <strong>favoris</strong>",
     "A file or folder has been <strong>changed</strong>" : "Un fichier ou un dossier a été <strong>modifié</strong>",
     "A favorite file or folder has been <strong>changed</strong>" : "Un fichier ou un dossier favori a été <strong>modifié </strong>",
-    "All files" : "Tous les fichiers",
     "Upload (max. %s)" : "Envoi (max. %s)",
     "Accept" : "Accepter",
     "Reject" : "Refuser",
@@ -167,38 +168,47 @@ OC.L10N.register(
     "Your ownership transfer of {path} to {user} has completed." : "Votre transfert de propriété de {path} à {user} est terminé.",
     "The ownership transfer of {path} from {user} has completed." : "Le transfert de propriété de {path} de {user} est terminé.",
     "in %s" : "dans %s",
-    "File Management" : "Gestion de fichier",
+    "File Management" : "Gestion de fichiers",
+    "Current directory path" : "Chemin du répertoire courant",
     "Reload current directory" : "Rafraîchir le dossier courant",
     "Go to the \"{dir}\" directory" : "Aller au dossier \"{dir}\"",
-    "Select the row for {displayName}" : "Sélectionner la ligne pour {displayName}",
-    "Rename file" : "Renommer le fichier",
-    "File name" : "Nom du fichier",
-    "A long time ago" : "Il y a longtemps",
-    "Download file {name}" : "Télécharger le fichier {name}",
+    "Drag and drop files here to upload" : "Glissez-déposez les fichiers ici pour les téléverser",
+    "Your have used your space quota and cannot upload files anymore" : "Vous avez utilisé votre quota d'espace et vous ne pouvez plus téléverser de fichiers",
+    "You don’t have permission to upload or create files here" : "Vous n'avez pas la permission d'envoyer ou de créer des fichiers ici",
+    "Upload successful" : "Téléversement réussi",
     "\"{displayName}\" action executed successfully" : "Action \"{displayName}\" exécutée avec succès",
     "\"{displayName}\" action failed" : "Échec de l'action \"{displayName}\"",
+    "Toggle selection for file \"{displayName}\"" : "Basculer la sélection pour le fichier « {displayName} »",
+    "Toggle selection for folder \"{displayName}\"" : "Basculer la sélection pour le dossier « {displayName} »",
+    "Rename file" : "Renommer le fichier",
+    "File name" : "Nom du fichier",
+    "Folder name" : "Nom du dossier",
+    "This node is unavailable" : "Ce nœud est indisponible ",
+    "Download file {name}" : "Télécharger le fichier {name}",
     "\"{name}\" is not an allowed filetype." : "\"{name}\" n'est pas un type de fichier autorisé.",
     "{newName} already exists." : "{newName} existe déjà.",
+    "\"{char}\" is not allowed inside a file name." : "\"{char}\" n'est pas autorisé dans un nom de fichier.",
     "Name cannot be empty" : "Le nom ne peut pas être vide",
     "Another entry with the same name already exists" : "Une autre entrée avec le même nom existe déjà",
-    "Renamed \"{oldName}\" to \"{newName}\"" : "Renommer \"{oldName}\" en \"{newName}\"",
+    "Renamed \"{oldName}\" to \"{newName}\"" : "\"{oldName}\" renommé en \"{newName}\"",
     "Could not rename \"{oldName}\", it does not exist any more" : "Impossible de renommer \"{oldName}\", il n'existe plus.",
-    "The name \"{newName}\"\" is already used in the folder \"{dir}\". Please choose a different name." : "Le nom \"{newName}\"\" est déjà utilisé dans le dossier \"{dir}\". Merci de choisir un autre nom.",
+    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Le nom \"{newName}\" est déjà utilisé dans le dossier \"{dir}\". Veuillez choisir un autre nom.",
     "Could not rename \"{oldName}\"" : "Impossible de renommer \"{oldName}\"",
+    "Could not copy {file}. {message}" : "Impossible de copier {file}. {message}",
+    "Could not move {file}. {message}" : "Impossible de déplacer {file}. {message}",
     "Total rows summary" : "Récapitulatif du nombre total de lignes",
-    "Select all" : "Tout sélectionner",
-    "Unselect all" : "Tout désélectionner",
+    "Toggle selection for all files and folders" : "Basculer la sélection pour tous les fichiers et dossiers",
     "\"{displayName}\" failed on some elements " : "\"{displayName}\" a échoué sur certains éléments",
-    "\"{displayName}\" batch action executed successfully" : "Le traitement par lot \"{displayName}\" a été exécuté avec succès",
-    "ascending" : "ascendant",
-    "descending" : "descendant",
-    "Sort list by {column} ({direction})" : "Trier la liste par {column} ({direction})",
+    "\"{displayName}\" batch action executed successfully" : "L'action « {displayName} » par lot a été exécutée avec succès",
     "List of files and folders." : "Liste des fichiers et dossiers.",
+    "Column headers with buttons are sortable." : "L'entête des colonnes avec des boutons sont triables.",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Cette liste n'est pas entièrement affichée pour des raisons de performances. Les fichiers seront affichés au fur et à mesure que vous naviguerez dans la liste.",
+    "File not found" : "Fichier non trouvé",
     "Storage informations" : "Informations sur le stockage",
     "{usedQuotaByte} used" : "{usedQuotaByte} utilisés",
     "{relative}% used" : "{relative}% utilisés",
     "Could not refresh storage stats" : "Impossible de rafraîchir les statistiques de stockage",
+    "Your storage is full, files can not be updated or synced anymore!" : "Votre espace de stockage est plein. Les fichiers ne peuvent plus être mis à jour ni synchronisés !",
     "Transfer ownership of a file or folder" : "Transférer la propriété d'un fichier ou d'un dossier",
     "Choose file or folder to transfer" : "Sélectionnez un fichier ou un dossier à transférer",
     "Change" : "Modifier",
@@ -211,20 +221,33 @@ OC.L10N.register(
     "Ownership transfer request sent" : "Requête de transfert de propriété envoyée",
     "Cannot transfer ownership of a file or folder you do not own" : "Impossible de transférer la propriété d'un fichier ou d'un dossier que vous ne possédez pas",
     "Select file or folder to link to" : "Sélectionnez le fichier ou le dossier à lier",
+    "Choose file" : "Choisir un fichier",
+    "Choose {file}" : "Choisir {file}",
+    "Add" : "Ajouter",
     "Loading current folder" : "Chargement du dossier courant",
     "No files in here" : "Aucun fichier",
     "Upload some content or sync with your devices!" : "Déposez du contenu ou synchronisez vos appareils !",
     "Go to the previous folder" : "Aller au dossier précédent",
     "Go back" : "Revenir en arrière",
+    "Share" : "Partager",
+    "Shared by link" : "Partagés par lien",
+    "Shared" : "Partagé",
+    "Switch to list view" : "Basculer en vue liste",
+    "Switch to grid view" : "Basculer en vue grille",
+    "Error during upload: {message}" : "Erreur lors du téléversement : {message}",
+    "Error during upload, status code {status}" : "Erreur lors du téléversement, code d'état {status}",
+    "Unknown error during upload" : "Erreur inconnue lors du téléversement",
     "Open the files app settings" : "Ouvrir les paramètres de l'application Fichiers",
-    "Files settings" : "Paramètres des fichiers",
+    "Files settings" : "Paramètres de Fichiers",
     "File cannot be accessed" : "Impossible d'accéder au fichier",
-    "You might not have have permissions to view it, ask the sender to share it" : "Vous n’avez peut-être pas les autorisations pour le voir, demandez à l’expéditeur de le partager",
     "Sort favorites first" : "Trier les favoris d'abord",
+    "Sort folders before files" : "Trier les dossiers avant les fichiers",
     "Show hidden files" : "Afficher les fichiers masqués",
     "Crop image previews" : "Afficher en miniatures carrées",
+    "Enable the grid view" : "Activer la vue mosaïque",
     "Additional settings" : "Paramètres supplémentaires",
     "WebDAV" : "WebDAV",
+    "WebDAV URL" : "URL WebDAV",
     "Copy to clipboard" : "Copier dans le presse-papiers",
     "Use this address to access your Files via WebDAV" : "Utilisez cette adresse pour accéder à vos fichiers via WebDAV",
     "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Si vous avez activé le 2FA, vous devez créer et utiliser un nouveau mot de passe d'application en cliquant ici.",
@@ -239,40 +262,71 @@ OC.L10N.register(
     "Blank" : "Vide",
     "Unable to create new file from template" : "Impossible de créer un nouveau fichier à partir du modèle",
     "Delete permanently" : "Supprimer définitivement",
+    "Destination is not a folder" : "La destination n'est pas un dossier",
+    "This file/folder is already in that directory" : "Ce fichier/dossier se trouve déjà dans ce dossier",
+    "You cannot move a file/folder onto itself or into a subfolder of itself" : "Vous ne pouvez pas déplacer un fichier/dossier sur lui-même ou dans un sous-dossier de celui-ci",
+    "(copy)" : "(copier)",
+    "(copy %n)" : "(copier %n)",
+    "A file or folder with that name already exists in this folder" : "Un fichier ou un dossier portant ce nom existe déjà dans ce dossier",
+    "The files is locked" : "Le fichier est verrouillé",
+    "The file does not exist anymore" : "Le fichier n'existe plus",
+    "Choose destination" : "Choisir la destination",
+    "Copy to {target}" : "Copier vers {target}",
+    "Move to {target}" : "Déplacer vers {target}",
+    "Cancelled move or copy operation" : "Opération de déplacement ou de copie annulée",
+    "Move or copy operation failed" : "L'opération de copie ou de déplacement a échoué",
     "Open folder {displayName}" : "Ouvrir le dossier {displayName}",
+    "Open in Files" : "Ouvrir dans Fichiers",
     "Open details" : "Ouvrir les détails",
-    "Set up templates folder" : "Configurer le dossier des modèles",
-    "Templates" : "Modèles",
     "Create new templates folder" : "Créer un nouveau dossier de modèles",
+    "Templates" : "Modèles",
     "Unable to initialize the templates directory" : "Impossible d'initialiser le dossier des modèles",
+    "Created new folder \"{name}\"" : "Nouveau dossier \"{name}\" créé",
+    "One of the dropped files could not be processed" : "L'un des fichiers déposés n'a pas pu être traité",
+    "Uploading \"{filename}\" failed" : "Le téléversement de « {filename} » a échoué",
+    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} dossier","{folderCount} dossiers","{folderCount} dossiers"],
+    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} fichier","{fileCount} fichiers","{fileCount} fichiers"],
+    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 fichier et {folderCount} dossier","1 fichier et {folderCount} dossiers","1 fichier et {folderCount} dossiers"],
+    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} fichier et 1 dossier","{fileCount} fichiers et 1 dossier","{fileCount} fichiers et 1 dossier"],
+    "{fileCount} files and {folderCount} folders" : "{fileCount} fichiers et {folderCount} dossiers",
     "List of favorites files and folders." : "Liste des fichiers et dossiers favoris.",
     "No favorites yet" : "Aucun favori pour l'instant",
     "Files and folders you mark as favorite will show up here" : "Les fichiers et dossiers ajoutés à vos favoris apparaîtront ici",
-    "Toggle %1$s sublist" : "Basculer %1$s sous-liste",
-    "Toggle grid view" : "Activer/Désactiver l'affichage mosaïque",
+    "All files" : "Tous les fichiers",
+    "List of your files and folders." : "Liste de vos fichiers et dossiers.",
+    "List of recently modified files and folders." : "Liste des fichiers et dossiers récemment modifiés.",
+    "No recently modified files" : "Pas de fichiers récemment modifiés",
+    "Files and folders you recently modified will show up here." : "Les fichiers et dossiers que vous avez récemment modifiés apparaîtront ici.",
     "No entries found in this folder" : "Aucune entrée trouvée dans ce dossier",
+    "Select all" : "Tout sélectionner",
     "Upload too large" : "Données envoyées trop volumineuses",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Les fichiers que vous essayez d'envoyer dépassent la taille maximale d'envoi permise par ce serveur.",
     "Text file" : "Fichier texte",
     "New text file.txt" : "Nouveau fichier texte.txt",
-    "Storage invalid" : "Support de stockage invalide",
     "You can only favorite a single file or folder at a time" : "Vous ne pouvez ajouter qu'un seul favori de dossier ou de fichier à la fois.",
-    "Unlimited" : "Illimité",
     "Search users" : "Rechercher des utilisateurs",
+    "You might not have have permissions to view it, ask the sender to share it" : "Vous n’avez peut-être pas les autorisations pour le voir, demandez à l’expéditeur de le partager",
     "Cancel" : "Annuler",
-    "%s used" : "%s utilisés",
-    "%s%%" : "%s%%",
-    "%1$s of %2$s used" : "%1$s utilisés sur %2$s",
+    "Set up templates folder" : "Configurer le dossier des modèles",
+    "Toggle %1$s sublist" : "Basculer %1$s sous-liste",
+    "Toggle grid view" : "Activer/Désactiver l'affichage mosaïque",
     "Deleted files" : "Fichiers supprimés",
     "Shares" : "Partages",
     "Shared with others" : "Partagés avec d'autres",
     "Shared with you" : "Partagés avec vous",
-    "Shared by link" : "Partagés par lien",
     "Deleted shares" : "Partages supprimés",
     "Pending shares" : "Partages en attente",
+    "This file has the tag {tag}" : "Ce fichier a l'étiquette {tag}",
+    "This file has the tags {firstTags} and {lastTag}" : "Ce fichier a les étiquettes {firstTags} et {lastTag}",
+    "Select the row for {displayName}" : "Sélectionner la ligne pour {displayName}",
     "Open folder {name}" : "Ouvrir le dossier {name}",
+    "Unselect all" : "Tout désélectionner",
+    "ascending" : "ascendant",
+    "descending" : "descendant",
+    "Sort list by {column} ({direction})" : "Trier la liste par {column} ({direction})",
     "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "Cette liste n'est pas affichée en totalité pour des raisons de performances. Les fichiers seront affichés au fur et à mesure que vous parcourrez la liste.",
     "Search for an account" : "Chercher un compte",
+    "Choose" : "Choisir",
     "No files or folders have been deleted yet" : "Aucun fichier ou dossier n'a encore été supprimé"
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
